# Getting Started with Spark-Expectations

This guide will help you set up your environment, install the library, and understand the basic requirements for using Spark-Expectations in your data workflows.

## Prerequisites

### Python
- **Supported versions:** 3.9, 3.10, 3.11, 3.12 (recommended: latest 3.12.x)
### Java
- **Supported versions:** 8, 11, 17 


## Installation

You can install Spark-Expectations directly from [PyPI](https://pypi.org/project/spark-expectations/):

```sh
pip install -U spark-expectations
```

Or add it to your `requirements.txt ` or dependency manager (e.g., poetry, hatch, uv).



---

Ready to get started? Head to the [Quickstart](quickstart.md) for setting up hello world SparkExpectation job!